      SUBROUTINE BREMCROSS( Z, EEL, EPH, CROSS )

C	 Computes the relativistic cross section for electron-ion bremsstrahlung, 
C	 differential in photon energy.  
C	 The cross section is from Equation (4) of E. Haug (Atron. Astrophys. 326,
C	 417, 1997).  This closely follows Forumla 3BN of H. W. Koch & J. W.
C	 Motz (Rev. Mod. Phys. 31, 920, 1959), but requires fewer computationl steps.
C	 The multiplicative factor introduced by G. Elwert (Ann. Physik 34, 178, 
C	 1939) is included.  
C
C	 Z is the (mean) atomic number of the ions.
C	 EEL & EPH are the energies in keV of the incident electron and the radiated
C	 photon.
C	 CROSS is the returned value of the bremsstrahlung cross section.

	IMPLICIT NONE

	REAL*8		Z, EEL, EPH, CROSS
	REAL*8		E1, E2, K, P1, P2
	REAL*8		E1E2, P1P2, P2SUM, K2, CH1, CH2, CRTMP
	REAL*8		A1, A2, FE
C	Physical coefficients:
	REAL*8		PI, MC2, ALPHA, TWOAR02
	PARAMETER	( PI = 3.14159265, MC2 = 510.98D+00 )
	PARAMETER	( ALPHA = 7.29735308D-03 )
	PARAMETER	( TWOAR02 = 1.15893512D-27 )
C	Numerical coefficients:
	REAL*8		C11, C12, C13, C21, C22, C23
	PARAMETER	( C11=4.D0/3.D0, C12=7.D0/15.D0, C13=11.D0/70.D0 )
	PARAMETER	( C21=7.D0/20.D0, C22=9.D0/28.D0, C23=263.D0/210.D0 )

C	Calculate normalized photon and total electron energies

	K = EPH/MC2
	E1 = (EEL/MC2) + 1.D+00

C	Calculate energy of scattered electron and normalized momenta

	E2 = E1 - K
	P1 = DSQRT( E1**2 - 1.D+00 )

	IF( E2 .GT. 1.D0 ) THEN
	  P2 = DSQRT( E2**2 - 1.D+00 )
	ELSE
	  P2 = 0.D0
	END IF

C	Define frequently used quantities

	E1E2 = E1*E2
	P1P2 = P1*P2
	P2SUM = P1**2 + P2**2
	K2 = K**2

C	Define terms in cross section

	CH1 = (C11*E1E2+K2)-(C12*K2/E1E2)-(C13*K2*P2SUM/E1E2**4)

	CH2 = 1.D0+(1.D0/E1E2)+(C12*P2SUM/E1E2**3)+
     *	  (C22*K2+C23*P1P2**2)/E1E2**3

C	Collect terms

	CRTMP = CH1*(2.D0*DLOG((E1E2+P1P2-1.D0)/K)-(P1P2/E1E2)*CH2)

	CRTMP = Z**2 * CRTMP / (K*P1**2)

C	Compute the Elwert factor

	A1 = ALPHA * Z * E1/P1
	A2 = ALPHA * Z * E2/P2

	FE = (A2/A1)*(1.D0 - DEXP(-2.D0*PI*A1))/(1.D0 - DEXP(-2.D0*PI*A2))

C	Compute the differential cross section (units cm**2)

	CROSS = TWOAR02 * FE * CRTMP

	RETURN
	END