	PROGRAM BREMSPEC

C            VERSION 2              4 MARCH 2002
C
C    Address questions and comments to
C         Gordon D. Holman
C         NASA/Goddard Space Flight Center
C         Code 682
C         Greenbelt, MD 20771
C         Office phone: (301) 286-4636
C		E-Mail: holman@stars.gsfc.nasa.gov
C
C    Purpose -
C         This program computes the bremsstrahlung x-ray/gamma-ray spectrum 
C		from an isotropic electron distribution function provided in 
C		Subroutine DISTRN.  The units of the computed flux is photons per
C		second per keV per square centimeter.  
C
C    Files used - 
C		BREMCROSS.FOR		Bremsstrahlung cross section, differential in photon energy
C		BREMSPEC.FOR		This file
C		DMLINBR.FOR			Gaussian Quadrature integration routine
C		FDBPLBR.FOR			Electron distribution function
C
C    Subroutines -                                                       
C         DISTRN     Electron distribution function                          
C         FTHIN	   Function - provides integrand for bremsstrahlung integration
C		BREMCROSS  Bremsstrahlung cross section
C		DMLIN	   Function - Gaussian Quadrature integration routine
C		GAULEG	   Computes abscissas and weights for the Gaussian Quadrature integration
C
C    Reference - 
C         bremdoc.pdf
C
C    Revisions - 
C		Version 1: 5 March 2001
C		Version 2: 4 March 2002 - Option to specify electron flux density as input added
C									to Function FTHIN.  Expression for FTHIN corrected 
C									(PC replaced with BETA).  This corrects the photon 
C									spectrum at relativistic energies.  
  
      IMPLICIT NONE

      INTEGER*4   IERGQL, IERGQH, IPH, TIME0, ITIME, ITICK, IERALL

C	Maximum number of points for the Gaussian Quadrature integration, MAXFCN.
C	MAXFCN also determined the array sizes in Function DMLIN.
	INTEGER*4	MAXFCN
	PARAMETER	( MAXFCN = 2048 )

	REAL*8		EELOW, EEBRK, EEHIGH, EMIN, EMAXL, EMAX

	REAL*8		GAMLOW, GAMHIGH, GAMBRK, P, Q

	REAL*8		DENSTY, NTH, VOLUME, Z

	REAL*8		METHOD, RERR, DMLIN

	REAL*8		EPH, EEL, FLUXL, FLUXH, FLUX, FCOEFF, FTHIN

	REAL*8		PI, MC2, CLIGHT, AU

	PARAMETER	( PI = 3.14159265, MC2 = 510.98D+00 )

	PARAMETER	( CLIGHT = 2.9979D+10, AU = 1.496D+13 )

	COMMON		/DISTFCN/GAMLOW, GAMHIGH, GAMBRK, P, Q

	COMMON		/INTF/Z, EPH

	EXTERNAL	FTHIN

C	*****************************************************************
	NAMELIST/input/NTH,VOLUME,DENSTY,Z,P,Q,EELOW,EEBRK,EEHIGH,
     1			   GAMLOW,GAMBRK,GAMHIGH,RERR,METHOD
C	*****************************************************************
  
  	OPEN(unit=11,file="output.txt", status="REPLACE")
      OPEN(unit=12,file="error.txt", status="REPLACE")

      CALL SYSTEM_CLOCK(TIME0)

C			  ***Input parameters***

C				Electron distribution lower and upper cutoff energies
C				and break energy in keV.  

	EELOW	= 20.D+00
	EEBRK	= 200.D+00
	EEHIGH	= 1.0D+05

C				Double power law distribution spectral indices

	P		= 5.0D+00
	Q	    = 5.0D+00

C				Average atomic number (Z), density (NTH), and volume 
C				of thermal plasma.  Nonthermal electron density (DENSTY).

	Z		= 1.2D0
	DENSTY	= 2.0D+07
	NTH		= 2.0D+09
	VOLUME	= 1.0D+26

C			  ***Specify method of integration and relative error***

	METHOD  = 1
	RERR    = 0.001D+00

C				 Compute electron gammas corresponding to EELOW, EEBRK,
C				 and EEHIGH

	GAMLOW  = (EELOW/MC2) + 1.D0
	GAMBRK  = (EEBRK/MC2) + 1.D0
	GAMHIGH = (EEHIGH/MC2) + 1.D0

C				 Compute the numerical coefficient for the photon flux

	FCOEFF = (NTH*CLIGHT/(4.D0*PI*(AU**2)))*DENSTY*VOLUME/MC2**2

C				 Loop over photon energy in keV (EPH)

	DO IPH = 0, 40

	  EPH = 10D0**(0.5D0 + 0.1D0*IPH)

C	             The integration is performed in two steps
C				 because of the discontinuity at GAMBRK.

	  IF( EPH .LT. EEBRK ) THEN

	    EMIN  = DMAX1(EELOW, EPH)

		EMAXL = EEBRK

	    FLUXL = DMLIN(FTHIN,EMIN,EMAXL,MAXFCN,RERR,IERGQL)

		EMAX = EEHIGH

	    FLUXH = DMLIN(FTHIN,EEBRK,EMAX,MAXFCN,RERR,IERGQH)

	    FLUX  = FCOEFF*(FLUXL + FLUXH)

	  ELSE

		EMAX = EEHIGH

	    IERGQL = 0

	    FLUX = FCOEFF*DMLIN(FTHIN,EPH,EMAX,MAXFCN,RERR,IERGQH)

	  END IF

C				 Write results to screen and files

	  WRITE(6,'(2ES9.2,2(3X,I10))') EPH, FLUX, IERGQL, IERGQH

	  WRITE(11,'(2ES14.4)')  EPH, FLUX

	  WRITE(12,'(ES14.4,2I5)') EPH, IERGQL, IERGQH

	END DO


      CALL SYSTEM_CLOCK(ITIME, ITICK)
      IF (ITICK /= 0)                                                  
     1WRITE (6,'(" Processing complete in ", F9.3, " seconds")')       
     2      REAL(ITIME-TIME0)/REAL(ITICK)

C	Write the NAMELIST parameters to the output file.
	WRITE(11,NML=input)
  
      STOP 'Bremsstrahlung Computations Finished'
      END

CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC

	FUNCTION FTHIN( EEL )

C	Returns the integrand for the bremsstrahlung integration.

	IMPLICIT NONE

	REAL*8		EEL, FTHIN, Z, EPH

	REAL*8		GAMMA, BETA, FCN, CROSS

	REAL*8		PI, MC2, CLIGHT, AU

	PARAMETER	( PI = 3.14159265, MC2 = 510.98D+00 )

	PARAMETER	( CLIGHT = 2.9979D+10, AU = 1.496D+13 )

	COMMON		/INTF/Z, EPH

	GAMMA = (EEL/MC2) + 1.D0

	BETA = DSQRT( 1.D0 - 1.D0/GAMMA**2 )

	CALL DISTRN( GAMMA, FCN )

	CALL BREMCROSS( Z, EEL, EPH, CROSS )

	FTHIN = FCN * BETA * CROSS

C	Replace the above line with the following to have DISTRN specify
C	the normalized electron flux density rather than the number density.
C	Specify the total electron flux density with the input parameter DENSTY.  

C	FTHIN = FCN * CROSS / CLIGHT

	RETURN
	END